InputFile

Struct InputFile 

pub struct InputFile {
    pub path: PathBuf,
    pub archive_entry: Option<ArchiveEntryInfo>,
    pub sections: Vec<Option<Section>>,
}

Fields

path: PathBuf

Path to the input file on disk. In case of archives, multiple inputs may have the same path.

archive_entry: Option<ArchiveEntryInfo>

If the input is an archive, then contains information about where in the archive the file came from.

sections: Vec<Option<Section>>

Sections that were written to the output. Indexes correspond to the sections in the input file. Contains None for sections that were discarded or weren’t fully copied.